@@ -1,4 +1,4 @@
-#!/bin/bash
+#!/usr/bin/env bash
 #
 # install.sh [--uninstall] sourcefile targetfile [install options]
 #
@@ -36,6 +36,10 @@ do_install()
 
   install -d $(dirname $TARGET)
   install -p $PARAMS $SOURCE $TARGET
+  if [ -n "$LCOV_PERL_PATH" ] ; then
+    # Replace Perl interpreter specification
+    sed -e "1 s%^#\!.*perl.*$%#\!$LCOV_PERL_PATH%" -i $TARGET
+  fi
 }
 
 
@@ -51,7 +55,7 @@ do_uninstall()
   # Does target exist?
   if test -r $TARGET ; then
     # Is target of the same version as this package?
-    if diff -I '^our \$lcov_version' -I '^\.TH ' $SOURCE $TARGET >/dev/null; then
+    if diff -I '^our \$lcov_version' -I '^\.TH ' -I '^#!' $SOURCE $TARGET >/dev/null; then
       rm -f $TARGET
     else
       echo WARNING: Skipping uninstall for $TARGET - versions differ! >&2
